@@ -7,8 +7,6 @@ AUTH_USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', 'auth.USER')
 
 # Django 1.5+ compatibility
 if django.VERSION >= (1, 5):
-    from django.contrib.auth import get_user_model
-    User = get_user_model()
+    User = settings.AUTH_USER_MODEL
 else:
     from django.contrib.auth.models import User
-
