@@ -1,24 +1,24 @@
-from django.contrib.auth.models import User
 import factory
 
+from referral.compat import User
 from referral.models import Campaign, Referrer, UserReferrer
 
-class UserFactory(factory.Factory):
+class UserFactory(factory.django.DjangoModelFactory):
     FACTORY_FOR = User
 
-class CampaignFactory(factory.Factory):
+class CampaignFactory(factory.django.DjangoModelFactory):
     FACTORY_FOR = Campaign
 
     name = factory.Sequence(lambda n: "Test Campaign %s" % n)
     description = "Some long test description"
 
-class ReferrerFactory(factory.Factory):
+class ReferrerFactory(factory.django.DjangoModelFactory):
     FACTORY_FOR = Referrer
 
     name = factory.Sequence(lambda n: "Test Referrer %s" % n)
     description = "Some long test description"
 
-class UserReferrerFactory(factory.Factory):
+class UserReferrerFactory(factory.django.DjangoModelFactory):
     FACTORY_FOR = UserReferrer
 
     user = factory.LazyAttribute(lambda a: UserFactory())
